﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Text.RegularExpressions;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>

    public partial class MainWindow : Window
    {
        //Define and Register SSN Custom Dependency Property
        public static readonly DependencyProperty SSNProperty = 
            DependencyProperty.Register(
                "SSN", typeof(string), typeof(MainWindow),  
                new PropertyMetadata(
                    "000-00-0000", 
                    new PropertyChangedCallback(
                        MainWindow.OnSSNPropertyChanged)));
        

        //.NET Wrapper to process SSN custom dependency property
        public string SSN 
        { 
            get 
            { 
                return (string)GetValue(SSNProperty); 
            } 
            
            set 
            { 
                SetValue(SSNProperty, value); 
            } 
        }
    
    
        //Property change notification service implementation
        private static void OnSSNPropertyChanged
            (DependencyObject ssnvalue, DependencyPropertyChangedEventArgs e)
        {
            if (!Regex.IsMatch
                ((string)ssnvalue.GetValue(e.Property), @"^\d{3}-\d{2}-\d{4}$")) 
            {                              
                MessageBox.Show("Not a valid SSN");
                ssnvalue.SetValue(e.Property, "000-00-0000");
            }
        }

        //Define and Register IsIdentifier Custom Attached Property
        public static readonly DependencyProperty IsIdentifierProperty =
            DependencyProperty.RegisterAttached(
                "IsIdentifier", typeof(Boolean), typeof(MainWindow),
                new PropertyMetadata(false));


        //GetPropertyName and SetPropertyName Accessor for custom attached property
        public static void SetIsIdentifier(UIElement element, Boolean val)
        {
            element.SetValue(MainWindow.IsIdentifierProperty, val);
        }

        public static Boolean GetIsIdentifier(UIElement element)
        {
            return (Boolean)element.GetValue(MainWindow.IsIdentifierProperty);
        }
        

        public MainWindow()
        {
            InitializeComponent();

            DataContext = this;


            //UNCOMMENT THE FOLLOWING CODE TO SEE HOW TO ACCSS CUSTOM ATTACHED DEPENDENCY PROPERTY CODE-BEHIND


            //TextBlock codebehind_tb = new TextBlock();
            //codebehind_tb.VerticalAlignment = System.Windows.VerticalAlignment.Top;
            //codebehind_tb.HorizontalAlignment = System.Windows.HorizontalAlignment.Right;
            //codebehind_tb.Margin = new Thickness(5);
            //codebehind_tb.Text = "Social Security Number";
            //codebehind_tb.SetValue(Grid.RowProperty, 1);
            //codebehind_tb.SetValue(Grid.ColumnProperty, 0);
            //LayoutRoot.Children.Add(codebehind_tb);
          
            //Boolean IsIdentifierProperty_Value;

            //IsIdentifierProperty_Value = (Boolean)SSNTextBox.GetValue(MainWindow.IsIdentifierProperty);

            
            //UNCOMMENT THE FOLLOWING CODE TO SEE HOW TO ACCSS DEPENDENCY PROPERTY CODE-BEHIND

            //string txtpropertyvalue;
            
            ////Demonstration of Accessing TextBox Text Dependency Property

            ////Set Text Dependency Property Value of TextBox Control
            //NameTextBox.Text = "Enter Name Here";

            ////Get Text Dependency Property Value of TextBox Control
            //txtpropertyvalue = NameTextBox.Text;

            ////Demonstration of Accessing SSN Custom Dependency Property

            ////Set SSN Custom Dependency Property Value 
            //SSN = "123-45-6789";

            ////Get SSN Custom Dependency Property Value
            //txtpropertyvalue = SSN;
            
        }

        private void CommonButtonClickEvent(object sender, RoutedEventArgs e)
        {
            FrameworkElement SourceElement = e.Source as FrameworkElement;

            switch (SourceElement.Name)
            {
                case "SubmitButton":
                    MessageBox.Show(e.OriginalSource + " - Common Click Event Processed");
                    break;

                case "CancelButton":
                    MessageBox.Show(e.OriginalSource + " - Common Click Event Processed");
                    break;
            }

            e.Handled = true;
        }

        private void SubmitButton_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Submit Button Clicked");

            //e.Handled = true;
        }

        private void LayoutRoot_Loaded(object sender, RoutedEventArgs e)
        {
            SubmitButton.Click += new RoutedEventHandler(SubmitButton_Click);            
        }



    }
}
